Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1124)

Unified Diff: pkg/barback/lib/src/barback.dart

Issue 25376003: Add support for transformer clusters to barback. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Expose the Operator class. Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/barback/lib/src/barback.dart
diff --git a/pkg/barback/lib/src/barback.dart b/pkg/barback/lib/src/barback.dart
index 313d42cae1f9c6b364ac38afac574892a2a4ef93..1a1ffc97befcc280a0b5107aa56a5760ee8d1501 100644
--- a/pkg/barback/lib/src/barback.dart
+++ b/pkg/barback/lib/src/barback.dart
@@ -98,11 +98,11 @@ class Barback {
/// not successful.
Future<AssetSet> getAllAssets() => _graph.getAllAssets();
/// Sets the transformer phases for [package]'s assets to [transformers].
///
- /// To the extent that [transformers] is similar to the previous transformer
- /// phases for [package], the existing asset graph will be preserved.
- void updateTransformers(String package,
- Iterable<Iterable<Transformer>> transformers) =>
- _graph.updateTransformers(package, transformers);
+ /// To the extent that [operators] is similar to the previous operator phases
+ /// for [package], the existing asset graph will be preserved.
+ void updateOperators(String package,
+ Iterable<Iterable<Operator>> operators) =>
+ _graph.updateOperators(package, operators);
}

Powered by Google App Engine
@@ -98,11 +98,11 @@ class Barback {
/// not successful.
Future<AssetSet> getAllAssets() => _graph.getAllAssets();
- /// Sets the transformer phases for [package]'s assets to [transformers].
+ /// Sets the operator phases for [package]'s assets to [operators].
///
This is Rietveld 408576698